package uk.ac.cf.spring.demo.sports.Userdetail;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import java.util.List;


@Repository
public class UserDaoImpl implements UserDao {
    private final JdbcTemplate jdbc;
    private RowMapper<userdetails> userdetailsMapper;


    @Autowired
    public UserDaoImpl(JdbcTemplate aJdbc) {
        this.jdbc = aJdbc;
        // 设置 RowMapper
        setUserdetailsMapper();
    }

    // 设置 RowMapper，用于将 ResultSet 转换为 userdetails 对象
    private void setUserdetailsMapper() {
        userdetailsMapper = (rs, i) -> new userdetails(
                rs.getLong("id"),
                rs.getString("email"),
                rs.getString("password"),
                rs.getString("username"),
                rs.getString("role")
        );
    }

    @Override
    public List<userdetails> getAllUsers() {
        // 查询所有用户
        String sql = "SELECT * FROM userdetails";
        List<userdetails>users=jdbc.query(sql,userdetailsMapper);
        return users;
    }

    @Override
    public userdetails getUserById(Long id) {
        // 根据 ID 查询用户
        String sql = "SELECT * FROM userdetails WHERE id = ?";
        return jdbc.queryForObject(sql, userdetailsMapper, id);
    }

    @Override
    public userdetails getUserByUsername(String username) {
        return null;
    }


    @Override
    public void addUser(userdetails user) {
        // 插入新用户
        String sql = "INSERT INTO userdetails (email, username, password, role) VALUES (?, ?, ?, ?)";
        jdbc.update(sql,
                user.getEmail(),
                user.getPassword(),
                user.getUsername(),
                user.getRole()
        );
    }

    @Override
    public void updateUser(userdetails user) {
        // 更新用户信息
        String sql = "UPDATE userdetails SET email = ?, username = ?, password = ?, role = ? WHERE id = ?";
        jdbc.update(sql,
                user.getEmail(),
                user.getPassword(),
                user.getUsername(),
                user.getRole(),
                user.getId()
        );
    }

    @Override
    public void deleteUser(Long id) {
        // 删除用户
        String sql = "DELETE FROM userdetails WHERE id = ?";
        jdbc.update(sql, id);
    }
}
