package uk.ac.cf.spring.demo.user.controller;

import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.web.bind.annotation.*;
import uk.ac.cf.spring.demo.user.User;
import uk.ac.cf.spring.demo.user.UserRepository;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;

import java.util.Map;
import java.util.Optional;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import static uk.ac.cf.spring.demo.util.SecurityUtils.getCurrentUserRole;

@Controller
public class LoginController {

    @Autowired
    private UserRepository userRepository;

    @Autowired
    private BCryptPasswordEncoder passwordEncoder; // Automatically inject BCryptPasswordEncoder

    // Display the login page
    @GetMapping("/login")
    public String showLoginForm() {
        return "html/login.html"; // return login.html
    }

    // Login User
    @PostMapping("/api/users/login")
    public ResponseEntity<?> loginUser(@RequestBody User loginRequest) {
        // Find users based on their email address
        Optional<User> optionalUser = userRepository.findByEmail(loginRequest.getEmail());
        if (optionalUser.isEmpty()) {
            return ResponseEntity.badRequest().body("{\"message\": \"Invalid email or password\"}");
        }

        // Get the hashed password stored in the database
        User user = optionalUser.get();
        String storedHashedPassword = user.getPassword();

        // Verify that the password entered by the user matches the hashed password in the database
        if (!passwordEncoder.matches(loginRequest.getPassword(), storedHashedPassword)) {
            return ResponseEntity.badRequest().body("{\"message\": \"Invalid email or password\"}");
        }

        // If the password is verified
        return ResponseEntity.ok("{\"message\": \"Login successful\"}");
    }

    @GetMapping("/html/backGroundMatch.html")
    public ResponseEntity<String> accessRestrictedPage() {
        if (uk.ac.cf.spring.demo.util.SecurityUtils.isAdmin()) {
            return ResponseEntity.ok("Welcome, Admin!");
        } else {
            return ResponseEntity.status(HttpStatus.FORBIDDEN).body("Access Denied");
        }
    }

    @GetMapping("/users/current")
    public ResponseEntity<?> getCurrentUser() {
        String username = uk.ac.cf.spring.demo.util.SecurityUtils.getCurrentUsername();
        if (username == null) {
            return ResponseEntity.status(HttpStatus.UNAUTHORIZED).body("{\"message\": \"User not logged in\"}");
        }

        // Return user information
        return ResponseEntity.ok(Map.of(
                "username", username
        ));
    }



//    @GetMapping("/logout")
//    public ResponseEntity<?> logoutUser(HttpServletRequest request, HttpServletResponse response) {
//        SecurityContextHolder.clearContext(); // 清除用户认证信息
//        request.getSession().invalidate();    // 销毁会话
//        return ResponseEntity.ok("Logged out successfully");
//    }
}

