const USERS_API_URL = '/users';

window.onload = function () {
    fetchUsers();
};

// Fetch and display all users
function fetchUsers() {
    fetch(USERS_API_URL)
        .then(res => res.json())
        .then(data => {
            const tableBody = document.querySelector('#userTable tbody');
            tableBody.innerHTML = ''; // Clear previous rows

            data.forEach(user => {
                const userRow = document.createElement('tr');
                userRow.innerHTML = `
                    <td>${user.id}</td>
                    <td>${user.username}</td>
                    <td>${user.email}</td>
                    <td>${user.role}</td>
                    <td>
                        <button onclick="editUser(${user.id})">Edit</button>
                        <button onclick="deleteUser(${user.id})">Delete</button>
                    </td>
                `;
                tableBody.appendChild(userRow);
            });
        })
        .catch(err => console.error('Error fetching users:', err));
}

// Add a new user
function addUser() {
    const userForm = document.getElementById('userForm');
    const formData = new FormData(userForm);
    const userData = {};

    formData.forEach((value, key) => {
        userData[key] = value;
    });

    fetch(USERS_API_URL, {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify(userData),
    })
        .then(res => res.json())
        .then(() => {
            alert('User added successfully!');
            fetchUsers();
            userForm.reset();
        })
        .catch(err => console.error('Error adding user:', err));
}

// Delete a user by ID
function deleteUser(id) {
    fetch(`${USERS_API_URL}/${id}`, {
        method: 'DELETE',
    })
        .then(res => res.json())
        .then(() => {
            alert('User deleted successfully!');
            fetchUsers();
        })
        .catch(err => console.error('Error deleting user:', err));
}

// Edit a user and pre-fill the form
function editUser(id) {
    fetch(`${USERS_API_URL}/${id}`)
        .then(res => res.json())
        .then(user => {
            document.getElementById('username').value = user.username;
            document.getElementById('email').value = user.email;
            document.getElementById('password').value = ''; // Leave empty for security
            document.getElementById('role').value = user.role;

            const addButton = document.querySelector('#userForm button');
            addButton.textContent = 'Update User';
            addButton.setAttribute('onclick', `updateUser(${id})`);
        })
        .catch(err => console.error('Error editing user:', err));
}

// Update an existing user
function updateUser(id) {
    const userForm = document.getElementById('userForm');
    const formData = new FormData(userForm);
    const userData = {};

    formData.forEach((value, key) => {
        userData[key] = value;
    });

    fetch(`${USERS_API_URL}/${id}`, {
        method: 'PUT',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify(userData),
    })
        .then(res => res.json())
        .then(() => {
            alert('User updated successfully!');
            fetchUsers();
            userForm.reset();

            const addButton = document.querySelector('#userForm button');
            addButton.textContent = 'Add User';
            addButton.setAttribute('onclick', 'addUser()');
        })
        .catch(err => console.error('Error updating user:', err));
}