// Function to add fade-in animation
function applyFadeIn() {
    const tableBody = document.getElementById('ranking-table');
    tableBody.classList.add('fade-in'); // Add animation class
    setTimeout(() => tableBody.classList.remove('fade-in'), 500); // Remove class after animation
}

async function loadRankings() {
    const sport = document.getElementById('filter-sport').value;
    const sortOption = document.getElementById('sort-option').value;

    let apiUrl;

    if (sport === "all") {
        apiUrl = `/rankings/byallandsort?order=${sortOption}`;
    } else {
        apiUrl = `/rankings/bysportandsort?sport=${sport}&order=${sortOption}`;
    }
    try {
        const response = await fetch(apiUrl);
        if (!response.ok) {
            throw new Error(`HTTP error! Status: ${response.status}`);
        }

        const rankings = await response.json();

        const tableBody = document.getElementById('ranking-table');
        tableBody.innerHTML = ''; // Clear current table content

        // Add rows to the table
        rankings.forEach((ranking, index) => {
            const row = document.createElement('tr');
            row.innerHTML = `
                <td>${index + 1}</td>
                <td>${ranking.username || 'N/A'}</td>
                <td>${ranking.wins || 0}</td>
                <td>${ranking.sport || 'All'}</td>
            `;
            tableBody.appendChild(row);
        });

        // Apply fade-in effect
        applyFadeIn();
    } catch (error) {
        console.error('Error fetching rankings:', error);
    }
}
async function updateRankings() {
    try {
        const response = await fetch('/rankings/updatedata', {
            method: 'POST',
        });

        if (!response.ok) {
            throw new Error(`HTTP error! Status: ${response.status}`);
        }

        // Reload rankings after update
        loadRankings();
    } catch (error) {
        console.error('Error updating data:', error);
    }
}

// Add event listeners
document.getElementById('filter-sport').addEventListener('change', loadRankings);
document.getElementById('sort-option').addEventListener('change', loadRankings);

window.onload = loadRankings;


