package uk.ac.cf.spring.demo;

import com.fasterxml.jackson.databind.ObjectMapper;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.mockito.MockitoAnnotations;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.web.servlet.AutoConfigureMockMvc;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.boot.test.mock.mockito.MockBean;
import org.springframework.test.web.servlet.MockMvc;
import org.springframework.test.web.servlet.ResultMatcher;
import org.springframework.test.web.servlet.request.MockMvcRequestBuilders;
import uk.ac.cf.spring.demo.sports.match.MatchService;
import uk.ac.cf.spring.demo.user.User;
import uk.ac.cf.spring.demo.sports.match.MatchItem;

import java.util.Arrays;
import java.util.List;

import static org.mockito.Mockito.verify;
import static org.springframework.mock.http.server.reactive.MockServerHttpRequest.post;
import static org.springframework.test.web.client.match.MockRestRequestMatchers.jsonPath;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.delete;
import static org.springframework.test.web.servlet.result.MockMvcResultHandlers.print;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;
import static org.mockito.Mockito.*;

//Full container Mock MVC Integration
@SpringBootTest
@AutoConfigureMockMvc
public class MatchControllerIntTest {

    @Autowired
    private MockMvc mockMvc;

    @MockBean
    private MatchService matchService;

    private ObjectMapper objectMapper;


    @Test
    void testMatches() throws Exception {
        MatchItem match1 = new MatchItem(1L, "Pools", 1L, 2L, null, "completed", 2L, 3L, true, true, 2L);
        List<MatchItem> matches = Arrays.asList(match1);

        when(matchService.getMatchItems()).thenReturn(matches);

        mockMvc.perform(MockMvcRequestBuilders.get("/match"))
                .andDo(print())
                .andExpect(status().isOk());

        verify(matchService, times(1)).getMatchItems();
    }

    //    Integration Test with Mock MVC
    @Test
    void testMatchId() throws Exception {
        MatchItem match1 = new MatchItem(1L, "Pools", 1L, 2L, null, "completed", 2L, 3L, true, true, 2L);

        when(matchService.getMatchItemById(1L)).thenReturn(match1);

        mockMvc.perform(MockMvcRequestBuilders.get("/match/{id}", 1))
                .andExpect(status().isOk());

        verify(matchService, times(1)).getMatchItemById(1L);
    }

}
